Richtemplates — django-richtemplates v0.3.beta documentation

### Navigation

- index
- modules |
- next |
- django-richtemplates v0.3.beta documentation »

# Richtemplates

django-richtemplates is a set of templates (surprise!), template tags, media files providing presentation layer similar to what Richfaces library offers for J2EE developers - not outstanding but still nice looking and elegant.

We wanted to have ability to prototype Django projects/applications with some basic set of templates and thats why django-richtemplates was created. We use it for our company’s intranet applications but it can be also easily used for example projects in other Django pluggable applications.

## Sources and issue tracker

Sources may be found at bitbucket. You may file a bug there, too.

## License

django-richtemplates is an open source project released under MIT license. Copy of the license should be boundled with source code archive.

# Documentation

Installation and configuration topics:

- Quickstart
- Installation
- Configuration

Richtemplates

- Forms
  - LimitingModelForm
- Middleware
  - HTTP 403 Middleware
- Templates
  - Concepts and guidelines
  - Layout
- Skins
  - Default skin
  - Writing a skin
  - Adding new skin
  - Aqua skin
  - Django skin
  - Ruby skin
- User profiles
  - Using richtemplate’s user profile class
  - Subclassing profile class
- API Reference
  - Widgets

Included utilities:

- Management commands
  - `import_media` command

# Other topics

- Index
- Search Page

- Screenshots
- Documentation guidelines

### Navigation

- index
- modules |
- next |
- django-richtemplates v0.3.beta documentation »